@@ -1,9 +1,11 @@
 from __future__ import division, absolute_import, print_function
 
-import numpy as np
-from numpy.testing import assert_equal, TestCase, run_module_suite
+import pytest
 
-class TestDot(TestCase):
+import numpy as np
+from numpy.testing import assert_equal
+
+class TestDot(object):
     def test_matscalar(self):
         b1 = np.matrix(np.ones((3, 3), dtype=complex))
         assert_equal(b1*1.0, b1)
@@ -17,7 +19,3 @@ def test_diagonal():
     assert_equal(b1.diagonal(), diag_b1)
     assert_equal(np.diagonal(b1), array_b1)
     assert_equal(np.diag(b1), array_b1)
-
-
-if __name__ == "__main__":
-    run_module_suite()
